@@ -33,6 +33,7 @@ __all__ = (
     "FormatOptionsTypeDef",
     "InputTypeDef",
     "JobRunTypeDef",
+    "JobSampleTypeDef",
     "JobTypeDef",
     "JsonOptionsTypeDef",
     "OutputFormatOptionsTypeDef",
@@ -184,10 +185,15 @@ JobRunTypeDef = TypedDict(
         "RecipeReference": "RecipeReferenceTypeDef",
         "StartedBy": str,
         "StartedOn": datetime,
+        "JobSample": "JobSampleTypeDef",
     },
     total=False,
 )
 
+JobSampleTypeDef = TypedDict(
+    "JobSampleTypeDef", {"Mode": Literal["FULL_DATASET", "CUSTOM_ROWS"], "Size": int}, total=False
+)
+
 _RequiredJobTypeDef = TypedDict("_RequiredJobTypeDef", {"Name": str})
 _OptionalJobTypeDef = TypedDict(
     "_OptionalJobTypeDef",
@@ -211,6 +217,7 @@ _OptionalJobTypeDef = TypedDict(
         "RoleArn": str,
         "Timeout": int,
         "Tags": Dict[str, str],
+        "JobSample": "JobSampleTypeDef",
     },
     total=False,
 )
@@ -478,6 +485,7 @@ _OptionalDescribeJobResponseTypeDef = TypedDict(
         "RoleArn": str,
         "Tags": Dict[str, str],
         "Timeout": int,
+        "JobSample": "JobSampleTypeDef",
     },
     total=False,
 )
@@ -510,6 +518,7 @@ _OptionalDescribeJobRunResponseTypeDef = TypedDict(
         "RecipeReference": "RecipeReferenceTypeDef",
         "StartedBy": str,
         "StartedOn": datetime,
+        "JobSample": "JobSampleTypeDef",
     },
     total=False,
 )
